@@ -21,7 +21,6 @@
 
 typedef struct _ProcConfig ProcConfig;
 typedef struct _PrettyTable PrettyTable;
-typedef struct _LoadGraph LoadGraph;
 typedef struct _ProcInfo ProcInfo;
 typedef struct _ProcData ProcData;
 
@@ -31,9 +30,10 @@ typedef struct _ProcData ProcData;
 #include <gconf/gconf-client.h>
 #include <glibtop/cpu.h>
 
-#include "infoview.h"
 #include "smooth_refresh.h"
 
+#include "load-graph.h"
+
 enum
 {
 	ALL_PROCESSES,
@@ -54,7 +54,6 @@ struct _ProcConfig
 {
 	gint		width;
 	gint		height;
-        gboolean        show_more_info;
         gboolean	show_kill_warning;
         gboolean	show_hide_message;
         gboolean	show_tree;
@@ -75,57 +74,6 @@ struct _ProcConfig
 	gint 		num_cpus;
 };
 
-struct _PrettyTable {
-	GHashTable *app_hash;		/* apps gotten from libwnck */      
-	GHashTable *default_hash; 	/* defined in defaulttable.h */
-	gchar *datadir;
-};
-
-struct _LoadGraph {
-    
-    guint n;
-    gint type;
-    guint speed;
-    guint draw_width, draw_height;
-    guint num_points;
-    guint num_cpus;
-
-    guint allocated;
-
-    GdkColor *colors;
-    gfloat **data;
-    guint data_size;
-    guint *pos;
-
-    gint colors_allocated;
-    GtkWidget *main_widget;
-    GtkWidget *disp;
-    GtkWidget *cpu_labels[GLIBTOP_NCPU];
-    GtkWidget *memused_label;
-    GtkWidget *memtotal_label;
-    GtkWidget *mempercent_label;
-    GtkWidget *swapused_label;
-    GtkWidget *swaptotal_label;
-    GtkWidget *swappercent_label;
-    GtkWidget *net_in_label;
-    GtkWidget *net_in_total_label;
-    GtkWidget *net_out_label;
-    GtkWidget *net_out_total_label;
-    GdkPixmap *pixmap;
-    GdkGC *gc;
-    int timer_index;
-    
-    gboolean draw;
-
-    guint64 cpu_time [GLIBTOP_NCPU] [NCPUSTATES];
-    guint64 cpu_last [GLIBTOP_NCPU] [NCPUSTATES];
-    gboolean cpu_initialized;       
-
-    guint64 net_last_in, net_last_out;
-    float net_max;
-    GTimeVal net_time;
-};
-
 
 struct _ProcInfo
 {
@@ -144,11 +92,10 @@ struct _ProcInfo
 
 	guint64		cpu_time_last;
 
-	guint64		mem;
 	guint64		vmsize;
 	guint64		memres;
+	guint64		memwritable;
 	guint64		memshared;
-	guint64		memrss;
 	unsigned long	memxserver;
 
 	guint		pcpu; /* 0% - 100% */
@@ -173,7 +120,6 @@ struct _ProcData
 	GtkWidget	*loadavg;
 	GtkWidget	*endprocessbutton;
 	GtkWidget	*popup_menu;
-	Infoview	infoview;
 	GtkWidget	*disk_list;
 	ProcConfig	config;
 	LoadGraph	*cpu_graph;
@@ -183,8 +129,8 @@ struct _ProcData
 	gint		net_label_fixed_width;
 	ProcInfo	*selected_process;
 	GtkTreeSelection *selection;
-	gint		timeout;
-	gint		disk_timeout;
+	guint		timeout;
+	guint		disk_timeout;
 
 /*
    'info' is GList, which has very slow lookup. On each update, glibtop
@@ -241,4 +187,24 @@ void		procman_save_config (ProcData *data) G_GNUC_INTERNAL;
 void		procman_save_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefix) G_GNUC_INTERNAL;
 gboolean	procman_get_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefix) G_GNUC_INTERNAL;
 
+
+
+
+
+struct ReniceArgs
+{
+	ProcData *procdata;
+	int nice_value;
+};
+
+
+struct KillArgs
+{
+	ProcData *procdata;
+	int signal;
+};
+
+
+
+
 #endif /* _PROCMAN_PROCMAN_H_ */
